/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.batch.planner.internal.model.listener;

import com.liferay.batch.engine.BatchEngineTaskExecuteStatus;
import com.liferay.batch.engine.model.BatchEngineImportTask;
import com.liferay.batch.planner.constants.BatchPlannerLogConstants;
import com.liferay.batch.planner.model.BatchPlannerLog;
import com.liferay.batch.planner.service.BatchPlannerLogLocalService;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Matija Petanjek
 */
@Component(immediate = true, service = ModelListener.class)
public class BatchEngineImportTaskModelListener
	extends BaseModelListener<BatchEngineImportTask> {

	@Override
	public void onAfterCreate(BatchEngineImportTask batchEngineImportTask)
		throws ModelListenerException {

		_updateStatus(batchEngineImportTask);
	}

	@Override
	public void onAfterUpdate(
			BatchEngineImportTask originalBatchEngineImportTask,
			BatchEngineImportTask batchEngineImportTask)
		throws ModelListenerException {

		_updateStatus(batchEngineImportTask);
	}

	private void _updateStatus(BatchEngineImportTask batchEngineImportTask) {
		BatchPlannerLog batchPlannerLog =
			_batchPlannerLogLocalService.fetchBatchPlannerLog(
				String.valueOf(
					batchEngineImportTask.getBatchEngineImportTaskId()),
				false);

		if (batchPlannerLog == null) {
			if (_log.isDebugEnabled()) {
				_log.debug(
					"No batch planner log found for batch engine import task " +
						"ID " +
							batchEngineImportTask.getBatchEngineImportTaskId());
			}

			return;
		}

		batchPlannerLog.setStatus(
			BatchPlannerLogConstants.getStatus(
				BatchEngineTaskExecuteStatus.valueOf(
					batchEngineImportTask.getExecuteStatus())));

		_batchPlannerLogLocalService.updateBatchPlannerLog(batchPlannerLog);
	}

	private static final Log _log = LogFactoryUtil.getLog(
		BatchEngineImportTaskModelListener.class);

	@Reference
	private BatchPlannerLogLocalService _batchPlannerLogLocalService;

}